RoundMode enum

Rounding mode 舍入模式

Inheritance
Available extensions

Values

round → const RoundMode

Round to nearest 四舍五入

floor → const RoundMode

Round down (floor) 向下舍入(地板)

ceil → const RoundMode

Round up (ceiling) 向上舍入(天花板)

truncate → const RoundMode

Truncate (remove decimal part) 截断(移除小数部分)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RoundMode>
A constant List of the values in this enum, in order of their declaration.